@@ -1,7 +1,6 @@
 /*============================================================================
-
-  WCSLIB 6.4 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2019, Mark Calabretta
+  WCSLIB 7.3 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2020, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -22,10 +21,10 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: wcsunits.h,v 6.4 2019/08/15 09:30:18 mcalabre Exp $
+  $Id: wcsunits.h,v 7.3.1.2 2020/08/17 11:19:09 mcalabre Exp mcalabre $
 *=============================================================================
 *
-* WCSLIB 6.4 - C routines that implement the FITS World Coordinate System
+* WCSLIB 7.3 - C routines that implement the FITS World Coordinate System
 * (WCS) standard.  Refer to the README file provided with WCSLIB for an
 * overview of the library.
 *
@@ -138,7 +137,7 @@
 *   unitstr   char []   Null-terminated character array containing the units
 *                       specification to be translated.
 *
-*                       Inline units specifications in the a FITS header
+*                       Inline units specifications in a FITS header
 *                       keycomment are also handled.  If the first non-blank
 *                       character in unitstr is '[' then the unit string is
 *                       delimited by its matching ']'.  Blanks preceding '['
@@ -348,21 +347,19 @@ extern "C" {
 extern const char *wcsunits_errmsg[];
 
 enum wcsunits_errmsg_enum {
-  UNITSERR_SUCCESS            =  0,	/* Success. */
-  UNITSERR_BAD_NUM_MULTIPLIER =  1,	/* Invalid numeric multiplier. */
-  UNITSERR_DANGLING_BINOP     =  2,	/* Dangling binary operator. */
-  UNITSERR_BAD_INITIAL_SYMBOL =  3,	/* Invalid symbol in INITIAL
-					   context. */
-  UNITSERR_FUNCTION_CONTEXT   =  4,	/* Function in invalid context. */
-  UNITSERR_BAD_EXPON_SYMBOL   =  5,	/* Invalid symbol in EXPON context. */
-  UNITSERR_UNBAL_BRACKET      =  6,	/* Unbalanced bracket. */
-  UNITSERR_UNBAL_PAREN        =  7,	/* Unbalanced parenthesis. */
-  UNITSERR_CONSEC_BINOPS      =  8,	/* Consecutive binary operators. */
-  UNITSERR_PARSER_ERROR       =  9,	/* Internal parser error. */
-  UNITSERR_BAD_UNIT_SPEC      = 10,	/* Non-conformant unit
-					   specifications. */
-  UNITSERR_BAD_FUNCS          = 11,	/* Non-conformant functions. */
-  UNITSERR_UNSAFE_TRANS       = 12	/* Potentially unsafe translation. */
+  UNITSERR_SUCCESS            =  0,	// Success.
+  UNITSERR_BAD_NUM_MULTIPLIER =  1,	// Invalid numeric multiplier.
+  UNITSERR_DANGLING_BINOP     =  2,	// Dangling binary operator.
+  UNITSERR_BAD_INITIAL_SYMBOL =  3,	// Invalid symbol in INITIAL context.
+  UNITSERR_FUNCTION_CONTEXT   =  4,	// Function in invalid context.
+  UNITSERR_BAD_EXPON_SYMBOL   =  5,	// Invalid symbol in EXPON context.
+  UNITSERR_UNBAL_BRACKET      =  6,	// Unbalanced bracket.
+  UNITSERR_UNBAL_PAREN        =  7,	// Unbalanced parenthesis.
+  UNITSERR_CONSEC_BINOPS      =  8,	// Consecutive binary operators.
+  UNITSERR_PARSER_ERROR       =  9,	// Internal parser error.
+  UNITSERR_BAD_UNIT_SPEC      = 10,	// Non-conformant unit specifications.
+  UNITSERR_BAD_FUNCS          = 11,	// Non-conformant functions.
+  UNITSERR_UNSAFE_TRANS       = 12	// Potentially unsafe translation.
 };
 
 extern const char *wcsunits_types[];
@@ -397,7 +394,7 @@ int wcsutrne(int ctrl, char unitstr[], struct wcserr **err);
 int wcsulexe(const char unitstr[], int *func, double *scale,
              double units[WCSUNITS_NTYPE], struct wcserr **err);
 
-/* Deprecated. */
+// Deprecated.
 int wcsunits(const char have[], const char want[], double *scale,
              double *offset, double *power);
 int wcsutrn(int ctrl, char unitstr[]);
@@ -408,4 +405,4 @@ int wcsulex(const char unitstr[], int *func, double *scale,
 }
 #endif
 
-#endif /* WCSLIB_WCSUNITS */
+#endif // WCSLIB_WCSUNITS
